// MCU : PIC 16F887
// External clock : Quartz 4 MHz
// Driving of 2 servomotors : - servomotor LOWER (360 turn) on portd.b0 (pin 19),
//                              > Servomotor TOWER PRO MG995 (360),
//                              > Timer 0,
//                            - servomotor UPPER (180/270 turn) on portd.b1 (pin 20),
//                              > Servomotor TOWER PRO MG996R (180/270),
//                              > Timer 1.
// LED is connected to portc.b2 (pin 17).

/* ----------------------------------------------------------------------------*/

unsigned int cnt0, i, j, k;              // unsigned int : 0 to 65535
unsigned int consigne_1, consigne_0;     // unsigned int : 0 to 65535
unsigned char *p0, *p1;                  // unsigned char *p0, *p1 : pointeurs qui stockent ladresse dun objet de type char
int joystick_X, joystick_Y;

volatile unsigned char flag_TMR1;

/* ----------------------------------------------------------------------------*/

void ADC_initialization()
{
 ADCON0 = 0b01000001;              // b0 = 1 (ADON) : le convertisseur A/N interne est activ.
                                   // b1 (GO/DONE)  : A/D Conversion Status bit.
                                   // b2, b3, b4, b5 (CHS0, CHS1, CHS2, CHS3) : Analog Channel Select bits.
                                   // b6 = 1 (ADSC0), b7 = 0 (ADSC1)          : fosc / 8 = 4 MHz / 8 = 0,5 MHz = 500 KHz
                                   //                                           tosc = 1 / fosc = 1 / 500 KHz = 0,002 mS = 2 uS.
                                   // 2 uS est le temps de conversion A/D d'un bit, TAD.
                                   // Pour une conversion totale sur 10 bits il faut 12 TAD.
                                   // Pour une conversion correcte il faut que TAD = 1,6 uS au minimum.
                                   // TAD = 2 uS / bit. 12 TAD = 24 uS pour 10 bits.

 ADCON1 = 0b10000000;              // b0 = b1 = b2 = b3 = 0 : Unimplemented. Read as '0'.
                                   // b4 = 0 (VCFG0)        : Voltage reference VDD.
                                   // b5 = 0 (VCFG1)        : Voltage reference VSS.
                                   // b6 = 0                : Unimplemented. Read as '0'.
                                   // b7 = 1                : ADFM (A/D result ForMat) = 1 (format justifi  droite).
                                   // Explication :
                                   //          ADRESH        |         ADRESL
                                   // b7|b6|b5|b4|b3|b2|b1|b0|b7|b6|b5|b4|b3|b2|b1|b0
                                   //  0| 0| 0| 0| 0| 0| r| r| r| r| r| r| r| r| r| r
                                   //    les 6 MSB = 0 |   rsultat r sur 10 bits
}

unsigned int ADC_read(unsigned char channel)
// Si message d'erreur "'ADC_read' Identifier redefined" pendant compilation, dans Library Manager dcocher ADC_Read.
// ADC_read est ma propre routine crite pour apprentissage. Je n'utilise pas ADC_Read de la librairie Mikroelektronika.
{
 unsigned int k;                   // Variable locale.
 ADCON0 = ADCON0 & 0b11000011;     // ADCON0 = 01000001
                                   //        & 11000011 (masque)
                                   // ADCON0 = 01000001
                                   // masque :
                                   // b0 = 1 (ADON)                               : pour prendre en compte l'tat du convertisseur A/D, en service (0) ou  l'arrt (1).
                                   // b1 = 1 (GO/DONE)                            : pour prendre en compte l'tat de la conversion A/D, en cours (1) ou termine (0).
                                   // b2 = b3 = b4 = b5 = 0 (CHS0 CHS1 CHS2 CHS3) : pour re initialiser au premier canal de conversion, le canal 0 (CHS0 = CHS1 = CHS2 = CHS3 = 0).
                                   // b6 = b7 = 1 (ADSC0 ADSC1)                   : pour prendre en compte la valeur du diviseur, de la vitesse de conversion, choisi.
 channel = channel << 2;           // Dcalage channel de 2 bits  gauche pour placer la valeur de channel dans bits b2 b3 b4 b5 (CHS0 CHS1 CHS2 CHS3).
 ADCON0 = ADCON0 | channel;        // OU logique bit  bit entre ADCON0 et channel.
 // ou ADCON0 |= channel;
 Delay_ms(2);                      // Dlais de 2 mS minimum. >>> A ajuster si besoin. <<<
 ADCON0.GO_DONE = 1;               // Dclenchement de la conversion A/N.
                                   // ou ADCON0.b2 = 1;
 _asm NOP;                         // Recommand par Microchip.
 while (ADCON0.GO_DONE == 1);      // Attendre que le bit GO.DONE passe  0.
 {
  k = ADRESL + (ADRESH * 256);     // XXX A REVOIR XXX
  //ou k = ADRESL + (ADRESH << 8);
  return(k);
 }
}

/* ----------------------------------------------------------------------------*/

// Timer2 (8 bits) : 20 mS period
// Prescaler 1:16
// Postscaler 1:5
// PR2 preload = 250
// TMR2 preload = 0
// Interrupt time : 20,005 mS

void Init_Timer2()
{
 // Timer 2 in timer mode :
 T2CON = 0x26;
 PR2 = 250;             // Timer2 8 bits register is preloaded with 250 in order to count from 250 to 256, 5 cycles of 20 mS = 100 mS,
                        // divided by postscaler value of 5 = 20 mS.
 TMR2IE_bit = 1;        // Sets Interrupt Enable bit to 1.
 INTCON = 0xC0;         // GIE = 1.
}

// Timer1 (16 bits) : Ton servomotor UPPER
// Prescaler 1:1
// TMR1 preload = 64536
// Interrupt time : 1 mS

void Init_Timer1()
{
 // Timer 1 in timer mode :
 T1CON = 0x01;          // T1CON register > b0 > TMR1ON bit = 1 > Timer1 is enabled.
                        //                > b1 > TMR1CS bit = 0 > Timer1 counts pulses from internal oscillator.
 TMR1IF_bit = 0;        // Sets Interrupt Flag bit to 0.
 TMR1H = 0xFC;          // Timer1 16 bits register is preloaded with 64536 in order to count from 64536 to 65536, 1000 cycles of 1 uS = 1 mS.
 TMR1L = 0x18;          //
 TMR1IE_bit = 1;        // Sets Interrupt Enable bit to 1.
 INTCON = 0xC0;         // INTCON register > b6 > PEIE bit = 1 > All unmasked peripheral interrupts are enabled.
                        //                 > b7 > GIE bit = 1 > All unmasked interrupts are enabled.
 flag_TMR1 = 1;         // Timer1 is counting.
}

// Timer0 (8 bits) : Ton servomotor LOWER
// Prescaler 1:1
// TMR0 Preload = 156
// Interrupt Time : 0,1 mS (100 uS)

void Init_Timer0()
{
 // Timer 0 in timer mode :
 OPTION_REG = 0x88;     // OPTION_REG register > b0 > PS0 bit = 0 > Prescaler rate : 1:1.
                        //                     > b3 > PSA bit = 1 > Prescaler is assigned to the wachdog timer in order to have prescaler rate of 1:1.
                        //                     > b7 > RBPU bit = 1 > PORTB pull-up resistors are disabled.
 TMR0 = 156;            // Timer0 8 bits register is preloaded with 156 in order to count from 156 to 256, 100 cycles of 1 uS = 100 uS = 0,1 mS.
 INTCON = 0xA0;         // INTCON register > b2 > TOIF bit = 0 > Resets the bit in order to allow TMR0 to count pulses from internal oscillator.
                        //                 > b5 > TOIE bit = 1 > TMR0 overflow interrupt is enabled.
                        //                 > b7 > GIE bit = 1 > All unmasked interrupts are enabled.
 cnt0 = 0;              // Resets "100 uS" counter.
}

/* ----------------------------------------------------------------------------*/

void Interrupt()
{
 if (TMR2IF_bit && TMR2IE_bit)      // After 20 mS elapsed with Timer2 ...
 //if (TMR2IF_bit == 1)
    {
     // Timer 0 :                   // Servomotor LOWER.
     TMR0IF_bit = 0;                // Resets Interrupt Flag.
     p0 = &consigne_0;
     TMR0 = *(p0);
     //TMR0 = 156;                  // Reloads Timer0 8 bits register with 156 in order to count from 156 to 256, 100 cycles of 1 uS = 100 uS = 0,1 mS.
     portd.b0 = 1;                  // Servomotor LOWER ON.
     portc.b2 = 1;                  // LED ON.

     // Timer 1 :                   // Servomotor UPPER.
     TMR1IF_bit = 0;                // Resets Interrupt Flag.
     p1 = &consigne_1;              // Initilization of pointeur p1 with memory address contained in consigne_1. p1 = l'adresse de consigne_1.
     TMR1L = *(p1);                 // Reloads TMR1L with value contained at memory address contained in consigne_1, pointed by p1. TMR1L = contenu de l'adresse de p1.
     TMR1H = *(p1+1);               // Reloads TMR1H with value contained at memory address contained in consigne_1, pointed by p1, incremented by + 1.
     //TMR1L = consigne_1 & 0x00FF; // Pour Essais # 5.1, 5.2.
     //TMR1H = consigne_1 >> 8;     // Pour Essais # 5.1, 5.2.
     //TMR1IE_bit = 1;              // Enables Interrupt.
     flag_TMR1 = 1;                 // Timer1 is counting.
     portd.b1 = 1;                  // Servomotor UPPER ON.
     portc.b2 = 1;                  // LED ON.

     // Restarts Timer 2 :
     TMR2IF_bit = 0;                // Resets Interrupt Flag.
     PR2 = 250;                     // Reloads Timer2 8 bits register with 250 in order to count from 250 to 256, 5 cycles of 20 mS = 100 mS,
                                    // divided by postscaler value of 5 = 20 mS.
    }

 if (TMR0IF_bit && TMR0IE_bit)      // After 100 uS elapsed with TMR0 ...
 //if (TMR0IF_bit == 1)
    {
     TMR0IF_bit = 0;
     TMR0 = *(p0);
     //TMR0 = 156;
     cnt0++;                        // Increments "100 uS" counter.
    }

 if (TMR1IF_bit && TMR1IE_bit)      // After n x 1 mS elapsed with TMR1 ...
 //if (TMR1IF_bit == 1)
    {
     TMR1IF_bit = 0;
     TMR1L = *(p1);
     TMR1H = *(p1+1);
     //TMR1L = consigne_1 & 0x00FF; // Pour Essais # 5.1, 5.2.
     //TMR1H = consigne_1 >> 8;     // Pour Essais # 5.1, 5.2.
     flag_TMR1 = 0;                 // Timer1 stops counting.
     portd.b1 = 0;                  // Servomotor UPPER OFF.
     portc.b2 = 0;                  // LED OFF.
    }
}

/* ----------------------------------------------------------------------------*/

void ton_servo_lower (unsigned int consigne_0)
{

 // consigne_0 : Ton servomotor LOWER (360)

 i = 0;

 do
  {
   Init_Timer2();                         // Restarts 20 mS delay.
   Init_Timer0();                         // Restarts 0,1 mS (100 uS) delay. Resets 100 uS counter cnt0 = 0.
   while(cnt0 < consigne_0)
        {
         portd.b0 = 1;                    // Servomotor LOWER ON.
         portc.b2 = 1;                    // LED ON.
        }
   portd.b0 = 0;
   portc.b2 = 0;
   i++;
  }
 //while(i < 2);                          // Temps de rotation du servomoteur ajustable :
                                          // - si rotation continue dans main(), valeur mini : 2,
                                          // - si rotation discontinue dans main() avec delay, valeur mini optimale : 5.
 while(i < 5);
 //while(i < 8);
 //while(i < 10);
 //while(i < 15);
 //while(i < 45);
 //while(i < 60);
}

void ton_servo_lower_with_turning_time (unsigned int consigne_0, unsigned int turning_time)
{

 // consigne_0 : Ton servomotor LOWER (360)

 i = 0;

 do
  {
   Init_Timer2();                         // Restarts 20 mS delay.
   Init_Timer0();                         // Restarts 0,1 mS (100 uS) delay. Resets 100 uS counter cnt0 = 0.
   while(cnt0 < consigne_0)
        {
         portd.b0 = 1;                    // Servomotor LOWER ON.
         portc.b2 = 1;                    // LED ON.
        }
   portd.b0 = 0;
   portc.b2 = 0;
   i++;
  }
 while(i < turning_time);                 // Temps de rotation du servomoteur ajustable :
                                          // - si rotation continue dans main(), valeur mini : 2,
                                          // - si rotation discontinue dans main() avec delay, valeur mini optimale : 5.
}

void ton_servo_upper (unsigned int consigne_1)
{

 // consigne_1 : Ton servomotor UPPER (180/270)

 i = 0;

 do
  {
   Init_Timer2();                         // Restarts 20 mS delay.
   Init_Timer1();                         // Restarts 1 mS.
   while(flag_TMR1 == 1)
        {
         portd.b1 = 1;                    // Servomotor UPPER ON..
         portc.b2 = 1;                    // LED ON.
        }
   portd.b1 = 0;
   portc.b2 = 0;
   i++;
  }
 //while(i < 2);                          // Temps de rotation du servomoteur ajustable (valeur mini : 5).
 //while(i < 10);
 //while(i < 15);
 //while(i < 45);
 while(i < 50);
 //while(i < 60);
}

/* ----------------------------------------------------------------------------*/

void main()
{
 TRISC = 0;                               // PORT C configur en sortie.
 PORTC = 0;                               // Initialisation du PORT C  0.
 TRISD = 0;                               // PORT D configur en sortie.
 PORTD = 0;                               // Initialisation du PORT D  0.

 ADC_initialization();

 // Essai # 1.1 : OK (TMR1L and TMR1H registers values). Servomotor LOWER 360 tourne en continu  DROITE et  GAUCHE dans le while(1).
 /*
 while(1)
 {
  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;
  consigne_1 = 65535 - 1400;              // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
  sprintl(*p1, "%5u", consigne_1);        // In Library Manager check box Sprintl and check box C_Type are selected automatically.
  Delay_ms(1225);                         // Dlais AJUSTABLE pour dfinir l'angle de rotation.

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;
  consigne_1 = 65535 - 1500;              // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
  sprintl(*p1, "%5u", consigne_1);        // In Library Manager check box Sprintl and check box C_Type are selected automatically.
  Delay_ms(2000);                         // Dlais AJUSTABLE pour dfinir l'angle de rotation.
 }
 */
 
 // >>> Essais 1 : SERVOMOTEUR 360 LOWER branch sur sortie SERVOMOTEUR 180/270 UPPER <<< //
 
 // Essai # 1.2 : OK (TMR1L and TMR1H registers values). Servomotor LOWER 360 tourne en continu  DROITE et  GAUCHE dans le while(1).
 /*
 while(1)
 {
  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;
  
  joystick_X = (ADC_read(0));             // Reads X axis value with channel 0 (AN0) on pin #2.
  
  if (joystick_X <= 500)
     {
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }
  
  if (joystick_X >= 524)
     {
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }
  
  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 1.3 : OK (TMR1L and TMR1H registers values). Servomotor LOWER 360 tourne en continu  DROITE et  GAUCHE dans le while(1).
 /*
 while(1)
 {
  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_X = (ADC_read(0));             // Reads X axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 250))
     {
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_X <= 250) && (joystick_X > 0))
     {
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_X >= 524) && (joystick_X < 774))
     {
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_X >= 774) && (joystick_X < 1024))
     {
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 2.1 : FAIL. Servomotor LOWER 360 ne tourne pas.
 /*
 while(1)
 {
  Init_Timer2();
  Init_Timer0();

  p0 = &TMR0;
    
  consigne_0 = 256 - 156;                 // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
  sprintl(*p0, "%3u", consigne_0);

  Init_Timer0();

  while(cnt0 < (consigne_0 / 10))
  {
   portd.b0 = 1;                          // Servomotor LOWER ON.
   portc.b2 = 1;                          // LED ON.
  }
  
  portd.b0 = 0;
  portc.b2 = 0;
 }
 */
 
 // Essai # 2.2 : OK. Servomotor LOWER 360 tourne en continu.
 /*
 while(1)
 {
  Init_Timer2();

  p0 = &TMR0;

  consigne_0 = 256 - 156;                 // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
  sprintl(*p0, "%3u", consigne_0);

  Init_Timer0();

  while(cnt0 < (consigne_0 / 10))
  {
   portd.b0 = 1;                          // Servomotor LOWER ON.
   portc.b2 = 1;                          // LED ON.
  }

  portd.b0 = 0;
  portc.b2 = 0;
 }
 */
 
 // Essai # 2.3.1 : OK. Servomotor LOWER 360 tourne en continu  gauche.
 /*
 while(1)
 {
  p0 = &TMR0;

  consigne_0 = 256 - 156;                 // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
  sprintl(*p0, "%3u", consigne_0);

  Init_Timer2();
  Init_Timer0();

  while(cnt0 < (consigne_0 / 10))
  {
   portd.b0 = 1;                          // Servomotor LOWER ON.
   portc.b2 = 1;                          // LED ON.
  }

  portd.b0 = 0;
  portc.b2 = 0;
 }
 */

 // Essai # 2.3.2 : OK. Servomotor LOWER 360 tourne en continu  droite.
 /*
 while(1)
 {
  p0 = &TMR0;

  consigne_0 = 256 - 186;                 // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
  sprintl(*p0, "%3u", consigne_0);

  Init_Timer2();
  Init_Timer0();

  while(cnt0 < (consigne_0 / 10))
  {
   portd.b0 = 1;                          // Servomotor LOWER ON.
   portc.b2 = 1;                          // LED ON.
  }

  portd.b0 = 0;
  portc.b2 = 0;
 }
 */
 
 // Essai # 2.4.1 : OK.
 /*
 while(1)
 {
  p0 = &TMR0;
  
  // Servomotor LOWER 360 tourne  gauche.
  
  consigne_0 = 256 - 156;                 // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
  sprintl(*p0, "%3u", consigne_0);

  i = 0;
  
  do
  {
   Init_Timer2();
   Init_Timer0();

   while(cnt0 < (consigne_0 / 10))
   {
    portd.b0 = 1;                         // Servomotor LOWER ON.
    portc.b2 = 1;                         // LED ON.
   }

   portd.b0 = 0;
   portc.b2 = 0;

   i++;
  }
  while (i < 6);
  
  delay_ms(1000);
  
  // Servomotor LOWER 360 tourne  droite.
  
  consigne_0 = 256 - 186;                 // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
  sprintl(*p0, "%3u", consigne_0);

  i = 0;

  do
  {
   Init_Timer2();
   Init_Timer0();

   while(cnt0 < (consigne_0 / 10))
   {
    portd.b0 = 1;                         // Servomotor LOWER ON.
    portc.b2 = 1;                         // LED ON.
   }

   portd.b0 = 0;
   portc.b2 = 0;

   i++;
  }
  while (i < 6);

  delay_ms(1000);
 }
 */
 
 // Essai # 2.4.2 : OK.
 /*
 while(1)
 {
  p0 = &TMR0;

  // Servomotor LOWER 360 tourne  gauche.

  consigne_0 = 256 - 156;                 // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
  sprintl(*p0, "%3u", consigne_0);

  i = 0;

  do
  {
   Init_Timer2();
   Init_Timer0();

   while(cnt0 < (consigne_0 / 10))
   {
    portd.b0 = 1;                         // Servomotor LOWER ON.
    portc.b2 = 1;                         // LED ON.
   }

   portd.b0 = 0;
   portc.b2 = 0;

   i++;
  }
  while (i < 6);

  delay_ms(1000);

  // Servomotor LOWER 360 tourne  droite.

  consigne_0 = 256 - 186;                 // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
  sprintl(*p0, "%3u", consigne_0);

  i = 0;

  do
  {
   Init_Timer2();
   Init_Timer0();

   while(cnt0 < (consigne_0 / 10))
   {
    portd.b0 = 1;                         // Servomotor LOWER ON.
    portc.b2 = 1;                         // LED ON.
   }

   portd.b0 = 0;
   portc.b2 = 0;

   i++;
  }
  while (i < 11);

  delay_ms(1000);
 }
 */
 
 // Essai # 3.1 : OK.
 /*
 while(1)
 {
  // Servomotor LOWER 360 :
  
  p0 = &TMR0;
  
  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 250))
     {
      consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X >= 524) && (joystick_X < 774))
     {
      consigne_0 = 256 - 186;             // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  Init_Timer2();
  Init_Timer1();

  // Servomotor UPPER 360 :

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  if ((joystick_Y <= 500) && (joystick_Y > 250))
     {
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 524) && (joystick_Y < 774))
     {
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y > 500) && (joystick_Y < 524))
     {
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 3.2 : OK.
 /*
 while(1)
 {
  // Servomotor LOWER 360 :

  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 250))
     {
      portd.b1 = 0;
      consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  if ((joystick_X <= 250) && (joystick_X > 0))
     {
      portd.b1 = 0;
      consigne_0 = 256 - 106;             // consigne_0 = 256 - 106 => 106  256 = 150 x 1 uS = 150 uS = 0,15 mS.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  if ((joystick_X >= 524) && (joystick_X < 774))
     {
      portd.b1 = 0;
      consigne_0 = 256 - 186;             // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  if ((joystick_X >= 774) && (joystick_X < 1024))
      {
      portd.b1 = 0;
      consigne_0 = 256 - 236;             // consigne_0 = 256 - 236 => 236  256 = 20 x 1 uS = 20 uS = 0,02 mS.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 360 :
  
  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  if ((joystick_Y <= 500) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 524) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y > 500) && (joystick_Y < 524))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 4.1 : OK.
 /*
 while(1)
 {
  // Servomotor LOWER 270 :

  Init_Timer2();
  Init_Timer0();
  
  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 250))
     {
      consigne_0 = 256 - 186;             // consigne_0 = 256 - 186 => 186  256 = 70 x 1 uS = 70 uS = 0,07 mS.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();
      
      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
  
  if ((joystick_X <= 250) && (joystick_X > 0))
     {
      consigne_0 = 256 - 236;             // consigne_0 = 256 - 236 => 236  256 = 20 x 1 uS = 20 uS = 0,02 mS.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }
     
  if ((joystick_X >= 524) && (joystick_X < 774))
     {
      consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X >= 774) && (joystick_X < 1024))
     {
      consigne_0 = 256 - 106;             // consigne_0 = 256 - 106 => 106  256 = 150 x 1 uS = 150 uS = 0,15 mS.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 360 :

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  if ((joystick_Y <= 500) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 524) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y > 500) && (joystick_Y < 524))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */

 // Essai # 4.2 : OK.
 /*
 while(1)
 {
  // Servomotor LOWER 270 : Robo-Soul Digital Servo LD-3015 MG (270)

  Init_Timer2();
  Init_Timer0();

  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 0))
     {
      consigne_0 = 256 - 226;             // consigne_0 = 256 - 226 => 226  256 = 30 x 1 uS = 30 uS = 0,03 mS.
                                          // ROTATION CONTINUE DROITE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X >= 524) && (joystick_X < 1024))
     {
      consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE.
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 360 : M0300 360 Digital Servo (360)

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  if ((joystick_Y <= 500) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 524) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y > 500) && (joystick_Y < 524))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 4.3.1 : En cours de mise au point ...
 /*
 while(1)
 {
  // Servomotor LOWER 270 : TOWER PRO M996R (270)

  Init_Timer2();
  Init_Timer0();

  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 0))
  //if ((joystick_X <= 500) && (joystick_X > 100))
     {
      consigne_0 = 256 - 226;             // consigne_0 = 256 - 226 => 226  256 = 30 x 1 uS = 30 uS = 0,03 mS.
                                          // ROTATION CONTINUE DROITE.
      //consigne_0 = 256 - (0.25 * joystick_X);
      //consigne_0 = joystick_X / 4;
      
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X >= 524) && (joystick_X < 1024))
  //if ((joystick_X >= 524) && (joystick_X < 924))
     {
      consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE.
      //consigne_0 = 256 - (0.25 * joystick_X);
      //consigne_0 = joystick_X / 4;
      
      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 270 : Robo-Soul Digital Servo LD-3015 MG (270)

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  //if ((joystick_Y <= 500) && (joystick_Y > 250))
  if ((joystick_Y <= 490) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y >= 524) && (joystick_Y < 774))
  if ((joystick_Y >= 534) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y > 500) && (joystick_Y < 524))
  if ((joystick_Y > 490) && (joystick_Y < 534))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 4.3.2 : En cours de mise au point ...
 /*
 while(1)
 {
  // Servomotor LOWER 270 : TOWER PRO M996R (270)

  Init_Timer2();
  Init_Timer0();

  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  //if ((joystick_X <= 500) && (joystick_X > 0))
  if ((joystick_X <= 500) && (joystick_X > 100))
     {
      //consigne_0 = 256 - 226;           // consigne_0 = 256 - 226 => 226  256 = 30 x 1 uS = 30 uS = 0,03 mS.
                                          // ROTATION CONTINUE DROITE.
      //consigne_0 = 256 - (0.25 * joystick_X);
      consigne_0 = joystick_X / 4;
      //consigne_0 = joystick_X / 5;

      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  //if ((joystick_X >= 524) && (joystick_X < 1024))
  if ((joystick_X >= 524) && (joystick_X < 924))
     {
      //consigne_0 = 256 - 156;             // consigne_0 = 256 - 156 => 156  256 = 100 x 1 uS = 100 uS = 0,1 mS.
                                          // ROTATION CONTINUE GAUCHE.
      //consigne_0 = 256 - (0.25 * joystick_X);
      consigne_0 = joystick_X / 4;
      //consigne_0 = joystick_X / 5;

      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 524))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 360 : TOWER PRO M996R (360) (Ancien 270 avec les 2 butes dtruites)

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  //if ((joystick_Y <= 500) && (joystick_Y > 250))
  if ((joystick_Y <= 490) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y >= 524) && (joystick_Y < 774))
  if ((joystick_Y >= 534) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y > 500) && (joystick_Y < 524))
  if ((joystick_Y > 490) && (joystick_Y < 534))
  //if ((joystick_Y > 250) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 */
 
 // Essai # 5.1 : En cours de mise au point ...

 while(1)
 {
  // Servomotor LOWER 270 : TOWER PRO M996R (270)

  Init_Timer2();
  Init_Timer0();

  p0 = &TMR0;

  joystick_X = (ADC_read(0));             // Reads Y axis value with channel 0 (AN0) on pin #2.

  if ((joystick_X <= 500) && (joystick_X > 5))
     {
      // ROTATION CONTINUE DROITE.
      consigne_0 = 100 + (joystick_X / 10);

      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X >= 512) && (joystick_X < 1012))
     {
      // ROTATION CONTINUE GAUCHE.
      consigne_0 = 150 + (joystick_X - 512) / 10;

      sprintl(*p0, "%3u", consigne_0);

      Init_Timer2();
      Init_Timer0();

      while(cnt0 < (consigne_0 / 10))
      {
       portd.b1 = 0;
       portd.b0 = 1;                      // Servomotor LOWER ON.
       portc.b2 = 1;                      // LED ON.
      }

      portd.b0 = 0;
      portc.b2 = 0;
     }

  if ((joystick_X > 500) && (joystick_X < 512))
     {
      portd.b1 = 0;
      portd.b0 = 0;
      portc.b2 = 0;
     }

  // Servomotor UPPER 360 : TOWER PRO M996R (360) (Ancien 270 avec les 2 butes dtruites)

  Init_Timer2();
  Init_Timer1();

  p1 = &TMR1L;

  joystick_Y = (ADC_read(1));             // Reads Y axis value with channel 1 (AN1) on pin #3.

  //if ((joystick_Y <= 500) && (joystick_Y > 250))
  if ((joystick_Y <= 490) && (joystick_Y > 250))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1500;          // consigne_1 = 65535 - 1500 => 64035  65535 = 1500 x 1 uS = 1,5 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y <= 250) && (joystick_Y > 0))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1750;          // consigne_1 = 65535 - 1750 => 63785  65535 = 1750 x 1 uS = 1,75 mS = Ton.
                                          // ROTATION CONTINUE GAUCHE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y >= 524) && (joystick_Y < 774))
  if ((joystick_Y >= 534) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1400;          // consigne_1 = 65535 - 1400 => 64135  65535 = 1400 x 1 uS = 1,4 mS = Ton.
                                          // ROTATION CONTINUE DROITE LENTE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  if ((joystick_Y >= 774) && (joystick_Y < 1024))
     {
      portd.b0 = 0;
      consigne_1 = 65535 - 1250;          // consigne_1 = 65535 - 1250 => 64285  65535 = 1250 x 1 uS = 1,25 mS = Ton.
                                          // ROTATION CONTINUE DROITE RAPIDE.
      sprintl(*p1, "%5u", consigne_1);    // In Library Manager check box Sprintl and check box C_Type are selected automatically.
      Delay_ms(1000);                     // Dlais AJUSTABLE pour dfinir l'angle de rotation.
     }

  //if ((joystick_Y > 500) && (joystick_Y < 524))
  if ((joystick_Y > 490) && (joystick_Y < 534))
  //if ((joystick_Y > 250) && (joystick_Y < 774))
     {
      portd.b0 = 0;
      portd.b1 = 0;
      portc.b2 = 0;
     }
 }
 
}